flask-oidc
==========

`OpenID Connect <http://openid.net/connect/>`_ support for `Flask <http://flask.pocoo.org/>`_.

Currently designed around Google's `oauth2client <https://github.com/google/oauth2client>`_ library
and `OpenID Connect implementation <https://developers.google.com/accounts/docs/OAuth2Login>`_.
May or may not interoperate with other OpenID Connect identity providers,
for example, Microsoft's `Azure Active Directory <http://msdn.microsoft.com/en-us/library/azure/dn499820.aspx>`_.
